NoSuccessfulJobError

Struct NoSuccessfulJobError 

pub struct NoSuccessfulJobError;
An error returned from the race function or the rush function.

This error indicates that no job completed successfully.
Either no jobs were provided to the function or all jobs panicked/failed to send results.